@@ -18,7 +18,7 @@ G_BEGIN_DECLS
 
 #define GDK_RENDERING_CAIRO
 #define GDK_RENDERING_GL
-#undef GDK_RENDERING_VULKAN
+#define GDK_RENDERING_VULKAN
 
 G_END_DECLS
 
