@@ -15,17 +15,14 @@
  * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GDK_DEVICE_TOOL_H__
-#define __GDK_DEVICE_TOOL_H__
+#pragma once
 
 #if !defined (__GDK_H_INSIDE__) && !defined (GTK_COMPILATION)
 #error "Only <gdk/gdk.h> can be included directly."
 #endif
 
-#include <gdk/gdkversionmacros.h>
 #include <gdk/gdktypes.h>
 
-
 G_BEGIN_DECLS
 
 #define GDK_TYPE_DEVICE_TOOL    (gdk_device_tool_get_type ())
@@ -60,20 +57,19 @@ typedef enum {
 } GdkDeviceToolType;
 
 GDK_AVAILABLE_IN_ALL
-GType gdk_device_tool_get_type (void) G_GNUC_CONST;
+GType               gdk_device_tool_get_type        (void) G_GNUC_CONST;
 
 GDK_AVAILABLE_IN_ALL
-guint64 gdk_device_tool_get_serial (GdkDeviceTool *tool);
+guint64             gdk_device_tool_get_serial      (GdkDeviceTool *tool);
 
 GDK_AVAILABLE_IN_ALL
-guint64 gdk_device_tool_get_hardware_id (GdkDeviceTool *tool);
+guint64             gdk_device_tool_get_hardware_id (GdkDeviceTool *tool);
 
 GDK_AVAILABLE_IN_ALL
-GdkDeviceToolType gdk_device_tool_get_tool_type (GdkDeviceTool *tool);
+GdkDeviceToolType   gdk_device_tool_get_tool_type   (GdkDeviceTool *tool);
 
 GDK_AVAILABLE_IN_ALL
-GdkAxisFlags gdk_device_tool_get_axes (GdkDeviceTool *tool);
+GdkAxisFlags        gdk_device_tool_get_axes        (GdkDeviceTool *tool);
 
 G_END_DECLS
 
-#endif /* __GDK_DEVICE_TOOL_H__ */
